==> maplibre-compose-expressions-android-0.6.2-sources.jar: commonMain/com/dayanruben/maplibrecompose/expressions/value/unions.kt <==
package com.dayanruben.maplibrecompose.expressions.value

import com.dayanruben.maplibrecompose.expressions.ast.Expression
import com.dayanruben.maplibrecompose.expressions.dsl.eq
import com.dayanruben.maplibrecompose.expressions.dsl.format
import com.dayanruben.maplibrecompose.expressions.dsl.gt
import com.dayanruben.maplibrecompose.expressions.dsl.gte
import com.dayanruben.maplibrecompose.expressions.dsl.interpolate
import com.dayanruben.maplibrecompose.expressions.dsl.lt
import com.dayanruben.maplibrecompose.expressions.dsl.lte
import com.dayanruben.maplibrecompose.expressions.dsl.neq
import com.dayanruben.maplibrecompose.expressions.dsl.switch

/** Represents and [Expression] that resolves to a value that can be an input to [format]. */
public sealed interface FormattableValue : ExpressionValue

/**
 * Represents an [Expression] that resolves to a value that can be compared for equality. See [eq]
 * and [neq].
 */
public sealed interface EquatableValue : ExpressionValue

/** Union type for an [Expression] that resolves to a value that can be matched. See [switch]. */
public sealed interface MatchableValue : ExpressionValue

/**
 * Union type for an [Expression] that resolves to a value that can be ordered with other values of
 * its type. See [gt], [lt], [gte], and [lte].
 *
 * @param T the type of the value that can be compared against for ordering.
 */
public sealed interface ComparableValue<T> : ExpressionValue

/**
 * Union type for an [Expression] that resolves to a value that can be interpolated. See
 * [interpolate].
 *
 * @param T the type of values that can be interpolated between.
 */
public sealed interface InterpolateableValue<T> : ExpressionValue

==> maplibre-compose-expressions-android-0.6.21-sources.jar: commonMain/com/dayanruben/maplibrecompose/expressions/value/unions.kt <==
package com.dayanruben.maplibrecompose.expressions.value

import com.dayanruben.maplibrecompose.expressions.ast.Expression
import com.dayanruben.maplibrecompose.expressions.dsl.eq
import com.dayanruben.maplibrecompose.expressions.dsl.format
import com.dayanruben.maplibrecompose.expressions.dsl.gt
import com.dayanruben.maplibrecompose.expressions.dsl.gte
import com.dayanruben.maplibrecompose.expressions.dsl.interpolate
import com.dayanruben.maplibrecompose.expressions.dsl.lt
import com.dayanruben.maplibrecompose.expressions.dsl.lte
import com.dayanruben.maplibrecompose.expressions.dsl.neq
import com.dayanruben.maplibrecompose.expressions.dsl.switch

/** Represents and [Expression] that resolves to a value that can be an input to [format]. */
public sealed interface FormattableValue : ExpressionValue

/**
 * Represents an [Expression] that resolves to a value that can be compared for equality. See [eq]
 * and [neq].
 */
public sealed interface EquatableValue : ExpressionValue

/** Union type for an [Expression] that resolves to a value that can be matched. See [switch]. */
public sealed interface MatchableValue : ExpressionValue

/**
 * Union type for an [Expression] that resolves to a value that can be ordered with other values of
 * its type. See [gt], [lt], [gte], and [lte].
 *
 * @param T the type of the value that can be compared against for ordering.
 */
public sealed interface ComparableValue<T> : ExpressionValue

/**
 * Union type for an [Expression] that resolves to a value that can be interpolated. See
 * [interpolate].
 *
 * @param T the type of values that can be interpolated between.
 */
public sealed interface InterpolatableValue<T> : ExpressionValue
